@@ -1,8 +1,4 @@
 from . import _cooley as cooley
 from . import _thetagpu as thetagpu
-from pipe import Pipe
 
-__all__ = (
-    'cooley',
-    'thetagpu'
-)
+__all__ = ("cooley", "thetagpu")
