@@ -6,6 +6,7 @@ from pydash import filter_ as filter
 from pydash import flatten, get, omit
 
 from .primitives import (
+    fetch,
     host,
     map,
     mapreduce,
@@ -14,6 +15,7 @@ from .primitives import (
     rank,
     reduce,
     scatter,
+    shard,
     size,
     stream,
 )
@@ -37,4 +39,6 @@ __all__ = (
     "host",
     "size",
     "filter",
+    "shard",
+    "fetch",
 )
